@@ -19,6 +19,7 @@ func NewSyncCommands(gitCommon *GitCommon) *SyncCommands {
 // Push pushes to a branch
 type PushOpts struct {
 	Force          bool
+	ForceWithLease bool
 	UpstreamRemote string
 	UpstreamBranch string
 	SetUpstream    bool
@@ -30,10 +31,11 @@ func (self *SyncCommands) PushCmdObj(task gocui.Task, opts PushOpts) (oscommands
 	}
 
 	cmdArgs := NewGitCmd("push").
-		ArgIf(opts.Force, "--force-with-lease").
+		ArgIf(opts.Force, "--force").
+		ArgIf(opts.ForceWithLease, "--force-with-lease").
 		ArgIf(opts.SetUpstream, "--set-upstream").
 		ArgIf(opts.UpstreamRemote != "", opts.UpstreamRemote).
-		ArgIf(opts.UpstreamBranch != "", opts.UpstreamBranch).
+		ArgIf(opts.UpstreamBranch != "", "HEAD:"+opts.UpstreamBranch).
 		ToArgv()
 
 	cmdObj := self.cmd.New(cmdArgs).PromptOnCredentialRequest(task)
@@ -58,7 +60,7 @@ func (self *SyncCommands) fetchCommandBuilder(fetchAll bool) *GitCommandBuilder
 }
 
 func (self *SyncCommands) FetchCmdObj(task gocui.Task) oscommands.ICmdObj {
-	cmdArgs := self.fetchCommandBuilder(self.UserConfig.Git.FetchAll).ToArgv()
+	cmdArgs := self.fetchCommandBuilder(self.UserConfig().Git.FetchAll).ToArgv()
 
 	cmdObj := self.cmd.New(cmdArgs)
 	cmdObj.PromptOnCredentialRequest(task)
@@ -70,7 +72,7 @@ func (self *SyncCommands) Fetch(task gocui.Task) error {
 }
 
 func (self *SyncCommands) FetchBackgroundCmdObj() oscommands.ICmdObj {
-	cmdArgs := self.fetchCommandBuilder(self.UserConfig.Git.FetchAll).ToArgv()
+	cmdArgs := self.fetchCommandBuilder(self.UserConfig().Git.FetchAll).ToArgv()
 
 	cmdObj := self.cmd.New(cmdArgs)
 	cmdObj.DontLog().FailOnCredentialRequest()
@@ -86,6 +88,7 @@ type PullOptions struct {
 	BranchName      string
 	FastForwardOnly bool
 	WorktreeGitDir  string
+	WorktreePath    string
 }
 
 func (self *SyncCommands) Pull(task gocui.Task, opts PullOptions) error {
@@ -93,8 +96,9 @@ func (self *SyncCommands) Pull(task gocui.Task, opts PullOptions) error {
 		Arg("--no-edit").
 		ArgIf(opts.FastForwardOnly, "--ff-only").
 		ArgIf(opts.RemoteName != "", opts.RemoteName).
-		ArgIf(opts.BranchName != "", opts.BranchName).
+		ArgIf(opts.BranchName != "", "refs/heads/"+opts.BranchName).
 		GitDirIf(opts.WorktreeGitDir != "", opts.WorktreeGitDir).
+		WorktreePathIf(opts.WorktreePath != "", opts.WorktreePath).
 		ToArgv()
 
 	// setting GIT_SEQUENCE_EDITOR to ':' as a way of skipping it, in case the user
@@ -110,7 +114,7 @@ func (self *SyncCommands) FastForward(
 ) error {
 	cmdArgs := self.fetchCommandBuilder(false).
 		Arg(remoteName).
-		Arg(remoteBranchName + ":" + branchName).
+		Arg("refs/heads/" + remoteBranchName + ":" + branchName).
 		ToArgv()
 
 	return self.cmd.New(cmdArgs).PromptOnCredentialRequest(task).Run()
