@@ -280,14 +280,7 @@ func (self *BasicCommitsController) createResetMenu(commit *models.Commit) error
 }
 
 func (self *BasicCommitsController) checkout(commit *models.Commit) error {
-	return self.c.Confirm(types.ConfirmOpts{
-		Title:  self.c.Tr.CheckoutCommit,
-		Prompt: self.c.Tr.SureCheckoutThisCommit,
-		HandleConfirm: func() error {
-			self.c.LogAction(self.c.Tr.Actions.CheckoutCommit)
-			return self.c.Helpers().Refs.CheckoutRef(commit.Hash, types.CheckoutRefOptions{})
-		},
-	})
+	return self.c.Helpers().Refs.CreateCheckoutMenu(commit)
 }
 
 func (self *BasicCommitsController) copyRange(*models.Commit) error {
@@ -311,8 +304,8 @@ func (self *BasicCommitsController) canCopyCommits(selectedCommits []*models.Com
 func (self *BasicCommitsController) handleOldCherryPickKey() error {
 	msg := utils.ResolvePlaceholderString(self.c.Tr.OldCherryPickKeyWarning,
 		map[string]string{
-			"copy":  keybindings.Label(self.c.UserConfig.Keybinding.Commits.CherryPickCopy),
-			"paste": keybindings.Label(self.c.UserConfig.Keybinding.Commits.PasteCommits),
+			"copy":  keybindings.Label(self.c.UserConfig().Keybinding.Commits.CherryPickCopy),
+			"paste": keybindings.Label(self.c.UserConfig().Keybinding.Commits.PasteCommits),
 		})
 
 	return errors.New(msg)
