@@ -33,18 +33,16 @@ func (self *PatchBuildingHelper) ValidateNormalWorkingTreeState() (bool, error)
 }
 
 // takes us from the patch building panel back to the commit files panel
-func (self *PatchBuildingHelper) Escape() error {
-	return self.c.PopContext()
+func (self *PatchBuildingHelper) Escape() {
+	self.c.Context().Pop()
 }
 
 // kills the custom patch and returns us back to the commit files panel if needed
 func (self *PatchBuildingHelper) Reset() error {
 	self.c.Git().Patch.PatchBuilder.Reset()
 
-	if self.c.CurrentStaticContext().GetKind() != types.SIDE_CONTEXT {
-		if err := self.Escape(); err != nil {
-			return err
-		}
+	if self.c.Context().CurrentStatic().GetKind() != types.SIDE_CONTEXT {
+		self.Escape()
 	}
 
 	if err := self.c.Refresh(types.RefreshOptions{
@@ -54,31 +52,32 @@ func (self *PatchBuildingHelper) Reset() error {
 	}
 
 	// refreshing the current context so that the secondary panel is hidden if necessary.
-	return self.c.PostRefreshUpdate(self.c.CurrentContext())
+	self.c.PostRefreshUpdate(self.c.Context().Current())
+	return nil
 }
 
-func (self *PatchBuildingHelper) RefreshPatchBuildingPanel(opts types.OnFocusOpts) error {
+func (self *PatchBuildingHelper) RefreshPatchBuildingPanel(opts types.OnFocusOpts) {
 	selectedLineIdx := -1
 	if opts.ClickedWindowName == "main" {
 		selectedLineIdx = opts.ClickedViewLineIdx
 	}
 
 	if !self.c.Git().Patch.PatchBuilder.Active() {
-		return self.Escape()
+		self.Escape()
+		return
 	}
 
 	// get diff from commit file that's currently selected
 	path := self.c.Contexts().CommitFiles.GetSelectedPath()
 	if path == "" {
-		return nil
+		return
 	}
 
-	ref := self.c.Contexts().CommitFiles.CommitFileTreeViewModel.GetRef()
-	to := ref.RefName()
-	from, reverse := self.c.Modes().Diffing.GetFromAndReverseArgsForDiff(ref.ParentRefName())
+	from, to := self.c.Contexts().CommitFiles.GetFromAndToForDiff()
+	from, reverse := self.c.Modes().Diffing.GetFromAndReverseArgsForDiff(from)
 	diff, err := self.c.Git().WorkingTree.ShowFileDiff(from, to, reverse, path, true)
 	if err != nil {
-		return err
+		return
 	}
 
 	secondaryDiff := self.c.Git().Patch.PatchBuilder.RenderPatchForFile(patch.RenderPatchForFileOpts{
@@ -92,17 +91,18 @@ func (self *PatchBuildingHelper) RefreshPatchBuildingPanel(opts types.OnFocusOpt
 
 	oldState := context.GetState()
 
-	state := patch_exploring.NewState(diff, selectedLineIdx, oldState, self.c.Log)
+	state := patch_exploring.NewState(diff, selectedLineIdx, context.GetView(), oldState)
 	context.SetState(state)
 	if state == nil {
-		return self.Escape()
+		self.Escape()
+		return
 	}
 
-	mainContent := context.GetContentToRender(true)
+	mainContent := context.GetContentToRender()
 
 	self.c.Contexts().CustomPatchBuilder.FocusSelection()
 
-	return self.c.RenderToMainViews(types.RefreshMainOpts{
+	self.c.RenderToMainViews(types.RefreshMainOpts{
 		Pair: self.c.MainViewPairs().PatchBuilding,
 		Main: &types.ViewUpdateOpts{
 			Task:  types.NewRenderStringWithoutScrollTask(mainContent),
