@@ -5,6 +5,7 @@ import (
 	"log"
 
 	"github.com/jesseduffield/gocui"
+	"github.com/jesseduffield/lazygit/pkg/gui/context"
 	"github.com/jesseduffield/lazygit/pkg/gui/controllers/helpers"
 	"github.com/jesseduffield/lazygit/pkg/gui/keybindings"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
@@ -32,7 +33,7 @@ func (gui *Gui) outsideFilterMode(f func() error) func() error {
 
 func (gui *Gui) validateNotInFilterMode() bool {
 	if gui.State.Modes.Filtering.Active() {
-		_ = gui.c.Confirm(types.ConfirmOpts{
+		gui.c.Confirm(types.ConfirmOpts{
 			Title:         gui.c.Tr.MustExitFilterModeTitle,
 			Prompt:        gui.c.Tr.MustExitFilterModePrompt,
 			HandleConfirm: gui.helpers.Mode.ExitFilterMode,
@@ -60,7 +61,7 @@ func (self *Gui) GetCheatsheetKeybindings() []*types.Binding {
 }
 
 func (self *Gui) keybindingOpts() types.KeybindingsOpts {
-	config := self.c.UserConfig.Keybinding
+	config := self.c.UserConfig().Keybinding
 
 	guards := types.KeybindingGuards{
 		OutsideFilterMode: self.outsideFilterMode,
@@ -192,18 +193,6 @@ func (self *Gui) GetInitialKeybindings() ([]*types.Binding, []*gocui.ViewMouseBi
 			Tooltip:     self.c.Tr.OpenCommandLogMenuTooltip,
 			OpensMenu:   true,
 		},
-		{
-			ViewName: "secondary",
-			Key:      gocui.MouseWheelUp,
-			Modifier: gocui.ModNone,
-			Handler:  self.scrollUpSecondary,
-		},
-		{
-			ViewName: "secondary",
-			Key:      gocui.MouseWheelDown,
-			Modifier: gocui.ModNone,
-			Handler:  self.scrollDownSecondary,
-		},
 		{
 			ViewName:    "main",
 			Key:         gocui.MouseWheelDown,
@@ -218,6 +207,12 @@ func (self *Gui) GetInitialKeybindings() ([]*types.Binding, []*gocui.ViewMouseBi
 			Description: self.c.Tr.ScrollUp,
 			Alternative: "fn+down",
 		},
+		{
+			ViewName: "secondary",
+			Key:      gocui.MouseWheelDown,
+			Modifier: gocui.ModNone,
+			Handler:  self.scrollDownSecondary,
+		},
 		{
 			ViewName: "secondary",
 			Key:      gocui.MouseWheelUp,
@@ -248,12 +243,6 @@ func (self *Gui) GetInitialKeybindings() ([]*types.Binding, []*gocui.ViewMouseBi
 			Modifier: gocui.ModNone,
 			Handler:  self.scrollDownConfirmationPanel,
 		},
-		{
-			ViewName: "confirmation",
-			Key:      gocui.MouseLeft,
-			Modifier: gocui.ModNone,
-			Handler:  self.handleConfirmationClick,
-		},
 		{
 			ViewName: "confirmation",
 			Key:      gocui.MouseWheelUp,
@@ -351,6 +340,18 @@ func (self *Gui) GetInitialKeybindings() ([]*types.Binding, []*gocui.ViewMouseBi
 }
 
 func (self *Gui) GetInitialKeybindingsWithCustomCommands() ([]*types.Binding, []*gocui.ViewMouseBinding) {
+	// if the search or filter prompt is open, we only want the keybindings for
+	// that context. It shouldn't be possible, for example, to open a menu while
+	// the prompt is showing; you first need to confirm or cancel the search/filter.
+	if currentContext := self.State.ContextMgr.Current(); currentContext.GetKey() == context.SEARCH_CONTEXT_KEY {
+		bindings := currentContext.GetKeybindings(self.c.KeybindingsOpts())
+		viewName := currentContext.GetViewName()
+		for _, binding := range bindings {
+			binding.ViewName = viewName
+		}
+		return bindings, nil
+	}
+
 	bindings, mouseBindings := self.GetInitialKeybindings()
 	customBindings, err := self.CustomCommandsClient.GetCustomCommandKeybindings()
 	if err != nil {
@@ -424,8 +425,14 @@ func (gui *Gui) SetKeybinding(binding *types.Binding) error {
 func (gui *Gui) SetMouseKeybinding(binding *gocui.ViewMouseBinding) error {
 	baseHandler := binding.Handler
 	newHandler := func(opts gocui.ViewMouseBindingOpts) error {
-		// we ignore click events on views that aren't popup panels, when a popup panel is focused
-		if gui.helpers.Confirmation.IsPopupPanelFocused() && gui.currentViewName() != binding.ViewName {
+		// we ignore click events on views that aren't popup panels, when a popup panel is focused.
+		// Unless both the current view and the clicked-on view are either commit message or commit
+		// description, because we want to allow switching between those two views by clicking.
+		isCommitMessageView := func(viewName string) bool {
+			return viewName == "commitMessage" || viewName == "commitDescription"
+		}
+		if gui.helpers.Confirmation.IsPopupPanelFocused() && gui.currentViewName() != binding.ViewName &&
+			(!isCommitMessageView(gui.currentViewName()) || !isCommitMessageView(binding.ViewName)) {
 			return nil
 		}
 
@@ -446,7 +453,9 @@ func (gui *Gui) callKeybindingHandler(binding *types.Binding) error {
 			return errors.New(disabledReason.Text)
 		}
 
-		gui.c.ErrorToast(gui.Tr.DisabledMenuItemPrefix + disabledReason.Text)
+		if len(disabledReason.Text) > 0 {
+			gui.c.ErrorToast(gui.Tr.DisabledMenuItemPrefix + disabledReason.Text)
+		}
 		return nil
 	}
 	return binding.Handler()
