@@ -57,7 +57,7 @@ func (gui *Gui) createMenu(opts types.CreateMenuOptions) error {
 		return err
 	}
 
-	_ = gui.c.PostRefreshUpdate(gui.State.Contexts.Menu)
+	gui.c.PostRefreshUpdate(gui.State.Contexts.Menu)
 
 	// TODO: ensure that if we're opened a menu from within a menu that it renders correctly
 	gui.c.Context().Push(gui.State.Contexts.Menu)
